@@ -192,7 +192,7 @@ $lang['analytics_single'] = 'A single domain';
 $lang['analytics_sub'] = 'One domain with multiple subdomains';
 $lang['analytics_multiple'] = 'Multiple top-level domains';
 $lang['analytics_universal'] = 'Universal Analytics';
-$lang['analytics_help'] = 'If Universal Analytics is chosen Advertiser support and enhanced link attribution options will be ignored';
+$lang['analytics_help'] = 'If Universal Analytics is chosen Advertiser support option will be ignored';
 $lang['analytics_support'] = 'Display Advertiser Support/Demographics and Interest reports tag?';
 $lang['analytics_enhanced_link'] = 'Include enhanced link attribution tag?';
 $lang['propertyid_title'] = 'Web Property ID (ie UA-XXXXXXXX-1)';
@@ -256,7 +256,12 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.9.2 25 June 2013. Stripped files appended with thumb_ from image dropdowns. Added process_pagedata tag to MetaMax output, making the Meta Data field redundant.</li>
 <li>Version 1.9.9.3 30 July 2013. Added trailing slash option for base tag, plus minor language updates spotted by Velden.</li>
 <li>Version 1.9.9.4 11 November 2013. Added option to include Demographics and Interest Reports tag into Analytics code.</li>
-<li>Version 1.9.9.5 20 November 2013. Added option to include enhanced link attribution tag into Analytics code.</li></ul>';
+<li>Version 1.9.9.5 20 November 2013. Added option to include enhanced link attribution tag into Analytics code.</li>
+<li>Version 1.9.9.6 18 February 2014. Minor bug fix for https urls.</li>
+<li>Version 1.9.9.7 13 May 2014. Added additional Twitter meta tags plus minor cleaning up.</li>
+<li>Version 1.9.9.8 17 June 2014. Added addition default keyword skip words and made county and country fields accept more than 5 chars.</li>
+<li>Version 1.9.9.8 17 July 2014. Amend to GA Universal tracking code.</li>
+</ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
